@@ -15,8 +15,9 @@ class CKANAPIError(Exception):
 
     If importing CKAN source fails then new versions of ParameterError,
     NotAuthorized, ValidationError, NotFound, ParameterError,
-    SearchQueryError and SearchError are created as subclasses of this
-    class so that they provide a helpful str() for tracebacks.
+    SearchQueryError, SearchError and SearchIndexError are created as
+    subclasses of this class so that they provide a helpful str() for
+    tracebacks.
     """
     def __str__(self):
         return repr(self.args)
@@ -55,11 +56,15 @@ except ImportError:
     class SearchError(CKANAPIError):
         pass
 
+    class SearchIndexError(CKANAPIError):
+        pass
+
 else:
     # import ckan worked, so these must not fail
     from ckan.logic import (ParameterError, NotAuthorized, NotFound,
                             ValidationError)
-    from ckan.lib.search import SearchQueryError, SearchError
+    from ckan.lib.search import (SearchQueryError, SearchError,
+                                 SearchIndexError)
 
 
 class ActionShortcut(object):
@@ -219,6 +224,7 @@ def prepare_action(action, data_dict=None, api_key=None):
     headers = {'Content-Type': 'application/json'}
     if api_key:
         headers['X-CKAN-API-Key'] = api_key
+        headers['Authorization'] = api_key
     url = '/api/action/' + action
     return url, data, headers
 
@@ -226,7 +232,7 @@ def prepare_action(action, data_dict=None, api_key=None):
 def reverse_apicontroller_action(status, response):
     """
     Make an API call look like a direct action call by reversing the
-    exception -> HTTP response translation that APIController.action does
+    exception -> HTTP response translation that ApiController.action does
     """
     try:
         parsed = json.loads(response)
@@ -247,6 +253,8 @@ def reverse_apicontroller_action(status, response):
     elif etype == 'Search Error':
         # I refuse to eval(emessage), even if it would be more correct
         raise SearchError(emessage)
+    elif etype == 'Search Index Error':
+        raise SearchIndexError(emessage)
     elif etype == 'Parameter Error':
         raise ParameterError(emessage)
     elif etype == 'Validation Error':
